@@ -57,10 +57,10 @@ Renderer::Renderer() {
 	for (auto* theme : themes) {
 		if (theme->identifier() == themeIdentifier) {
 		    provider->setCurrentTheme(theme);
-		    loadTheme(theme);
 		    break;
 		}
 	}
+	loadTheme(provider->currentTheme());
 	QObject::connect(m_themeProvider, &KgThemeProvider::currentThemeChanged, [this](const KgTheme* theme) {
 		loadTheme(theme);
 	});
